@@ -1,8 +1,11 @@
+import random
 import typing
 import urllib.parse
 from datetime import datetime
 from timeit import default_timer as timer
 
+from sqlalchemy import Column, Table, MetaData, create_engine
+
 from bakplane.bakplane_pb2 import (
     ResolveResourcePathResponse,
     ResolveResourceIntentResponse,
@@ -26,17 +29,57 @@ from bakplane.extensions.spark.utils import (
 from bakplane.utils import to_execution_statistics
 
 
+class JDBCStoreHelper(DataStoreHelper):
+    def __init__(
+            self,
+            user: str,
+            password: str,
+            host: str,
+            port: int,
+            database: str,
+            schema_name: str,
+            driver: str
+    ):
+        self.metadata = MetaData()
+        self.engine = create_engine(
+            f"{driver}://{user}:{password}@{host}:{port}/{database}"
+        )
+        self.schema_name = schema_name
+
+    def create_temporary_table(
+            self,
+            prefix: str,
+            columns: typing.List[Column],
+            rows: typing.List[typing.Dict[str, typing.Any]],
+    ) -> Table:
+        tbl = Table(
+            prefix
+            + "_"
+            + str(int(datetime.utcnow().timestamp()))
+            + "_"
+            + str(random.randint(1, 1000)),
+            self.metadata,
+            *columns,
+            schema=self.schema_name,
+        )
+
+        self.metadata.create_all(self.engine)
+        self.engine.execute(tbl.insert(), rows)
+
+        return tbl
+
+
 def __build_read_all_query(
-    r: ReadAllRequest, res: ResolveResourcePathResponse
+        r: ReadAllRequest, res: ResolveResourcePathResponse
 ) -> str:
     return f'select {", ".join(r.columns)} from {res.context["schema_name"]}.{res.context["table_name"]}'
 
 
 def __build_read_query(
-    r: ReadRequest,
-    res: ResolveResourceIntentResponse,
-    dialect,
-    store_helper: DataStoreHelper,
+        r: ReadRequest,
+        res: ResolveResourceIntentResponse,
+        dialect,
+        store_helper: DataStoreHelper,
 ) -> str:
     from sqlalchemy import (
         Table,
@@ -154,19 +197,19 @@ def __build_read_query(
 
         res = (
             select(blocks.columns)
-            .select_from(blocks.selectable)
-            .where(and_(*blocks.constraints))
+                .select_from(blocks.selectable)
+                .where(and_(*blocks.constraints))
         )
 
     query = str(
-        res.compile(dialect=dialect, compile_kwargs={"literal_binds": True},)
+        res.compile(dialect=dialect, compile_kwargs={"literal_binds": True}, )
     )
 
     return query
 
 
 def write_fn(
-    r: WriteRequest, res: ResolveResourcePathResponse, driver: str, url: str
+        r: WriteRequest, res: ResolveResourcePathResponse, driver: str, url: str
 ) -> WriteResponse:
     start = timer()
 
@@ -188,18 +231,18 @@ def write_fn(
 
 
 def __read_query(
-    spark, url: str, driver: str, query: str, user: str, password: str
+        spark, url: str, driver: str, query: str, user: str, password: str
 ):
     start = timer()
 
     df = (
         spark.read.format("jdbc")
-        .option("url", url)
-        .option("query", query)
-        .option("user", user)
-        .option("password", urllib.parse.unquote(password))
-        .option("driver", driver)
-        .load()
+            .option("url", url)
+            .option("query", query)
+            .option("user", user)
+            .option("password", urllib.parse.unquote(password))
+            .option("driver", driver)
+            .load()
     )
 
     end = timer()
@@ -207,16 +250,16 @@ def __read_query(
     return ReadResponse(
         df=df,
         execution_statistics=to_execution_statistics(start, end),
-        context={"query": query,},
+        context={"query": query, },
     )
 
 
 def read_all_fn(
-    ctx: typing.Any,
-    r: ReadAllRequest,
-    res: ResolveResourcePathResponse,
-    url: str,
-    driver: str,
+        ctx: typing.Any,
+        r: ReadAllRequest,
+        res: ResolveResourcePathResponse,
+        url: str,
+        driver: str,
 ) -> ReadResponse:
     return __read_query(
         spark=ctx,
@@ -229,13 +272,13 @@ def read_all_fn(
 
 
 def read_fn(
-    ctx: typing.Any,
-    r: ReadRequest,
-    res: ResolveResourceIntentResponse,
-    dialect,
-    url: str,
-    driver: str,
-    store_helper: DataStoreHelper,
+        ctx: typing.Any,
+        r: ReadRequest,
+        res: ResolveResourceIntentResponse,
+        dialect,
+        url: str,
+        driver: str,
+        store_helper: DataStoreHelper,
 ) -> ReadResponse:
     return __read_query(
         spark=ctx,
