@@ -1,4 +1,5 @@
 import typing
+from functools import lru_cache
 
 from bakplane.bakplane_pb2 import (
     ResolveResourcePathResponse,
@@ -12,6 +13,7 @@ from bakplane.extensions.base import (
     ReadRequest,
 )
 from bakplane.extensions.spark import PluginEntry, WriteResponse
+from bakplane.extensions.spark.stores.jdbc import JDBCStoreHelper
 
 DRIVER_NAME = "org.postgresql.Driver"
 
@@ -30,12 +32,32 @@ def get_registration():
     )
 
 
+@lru_cache()
+def get_helper(
+        user: str,
+        password: str,
+        host: str,
+        port: int,
+        database: str,
+        schema_name: str,
+):
+    return JDBCStoreHelper(
+        user=user,
+        password=password,
+        host=host,
+        port=port,
+        database=database,
+        schema_name=schema_name,
+        driver='postgresql+psycopg2'
+    )
+
+
 def __connection_string_url(c: ConnectionStringContext) -> str:
     return f'jdbc:postgresql://{c.context["host"]}:{c.context["port"]}/{c.context["database"]}'
 
 
 def __write_fn(
-    r: WriteRequest, res: ResolveResourcePathResponse
+        r: WriteRequest, res: ResolveResourcePathResponse
 ) -> WriteResponse:
     from bakplane.extensions.spark.stores.jdbc import write_fn
 
@@ -48,7 +70,7 @@ def __write_fn(
 
 
 def __read_all_fn(
-    ctx: typing.Any, r: ReadAllRequest, res: ResolveResourcePathResponse
+        ctx: typing.Any, r: ReadAllRequest, res: ResolveResourcePathResponse
 ) -> ReadResponse:
     from bakplane.extensions.spark.stores.jdbc import read_all_fn
 
@@ -62,7 +84,7 @@ def __read_all_fn(
 
 
 def __read_fn(
-    ctx: typing.Any, r: ReadRequest, res: ResolveResourceIntentResponse
+        ctx: typing.Any, r: ReadRequest, res: ResolveResourceIntentResponse
 ) -> ReadResponse:
     from bakplane.extensions.spark.stores.jdbc import read_fn
     from sqlalchemy.dialects import postgresql
@@ -74,4 +96,12 @@ def __read_fn(
         dialect=postgresql.dialect(),
         url=__connection_string_url(ConnectionStringContext(res.context)),
         driver=DRIVER_NAME,
+        store_helper=get_helper(
+            user=res.context["username"],
+            password=res.context["password"],
+            host=res.context["host"],
+            port=res.context["port"],
+            database=res.context["database"],
+            schema_name="temp_data",
+        ),
     )
